# Re-export all dataset constants from keywordsai-sdk
from keywordsai_sdk.constants.dataset_constants import (
    # Dataset Types
    DATASET_TYPE_LLM,
    DATASET_TYPE_SAMPLING,
    DatasetType,
    # Dataset Status
    DATASET_STATUS_INITIALIZING,
    DATASET_STATUS_READY,
    DATASET_STATUS_RUNNING,
    DATASET_STATUS_COMPLETED,
    DATASET_STATUS_FAILED,
    DATASET_STATUS_LOADING,
    DatasetStatus,
    # Dataset LLM Run Status
    DATASET_LLM_RUN_STATUS_PENDING,
    DATASET_LLM_RUN_STATUS_RUNNING,
    DATASET_LLM_RUN_STATUS_COMPLETED,
    DATASET_LLM_RUN_STATUS_FAILED,
    DATASET_LLM_RUN_STATUS_CANCELLED,
    DatasetLLMRunStatus,
)

DATASET_BASE_PATH = "datasets"
DATASET_CREATION_PATH = f"{DATASET_BASE_PATH}/create"
DATASET_LIST_PATH = f"{DATASET_BASE_PATH}/list"
DATASET_GET_PATH = f"{DATASET_BASE_PATH}"
DATASET_UPDATE_PATH = f"{DATASET_BASE_PATH}"
DATASET_DELETE_PATH = f"{DATASET_BASE_PATH}/delete"


__all__ = [
    # Dataset Types
    "DATASET_TYPE_LLM",
    "DATASET_TYPE_SAMPLING",
    "DatasetType",
    # Dataset Status
    "DATASET_STATUS_INITIALIZING",
    "DATASET_STATUS_READY",
    "DATASET_STATUS_RUNNING",
    "DATASET_STATUS_COMPLETED",
    "DATASET_STATUS_FAILED",
    "DATASET_STATUS_LOADING",
    "DatasetStatus",
    # Dataset LLM Run Status
    "DATASET_LLM_RUN_STATUS_PENDING",
    "DATASET_LLM_RUN_STATUS_RUNNING",
    "DATASET_LLM_RUN_STATUS_COMPLETED",
    "DATASET_LLM_RUN_STATUS_FAILED",
    "DATASET_LLM_RUN_STATUS_CANCELLED",
    "DatasetLLMRunStatus",
    # Dataset Paths
    "DATASET_BASE_PATH",
    "DATASET_CREATION_PATH",
    "DATASET_LIST_PATH",
    "DATASET_GET_PATH",
    "DATASET_UPDATE_PATH",
    "DATASET_DELETE_PATH",
]
